@@ -26,6 +26,9 @@ from dqueue.client import APIClient
 from dqueue.data import DataFacts
 
 class QueueProxy(DataFacts, Queue):
+    
+    def version(self):
+        return self.client.hub.version().response().result
 
     def list_queues(self, pattern):
         print(self.client.queues.list().response().result)
@@ -110,12 +113,15 @@ class QueueProxy(DataFacts, Queue):
     def insert_task_entry(self,task,state):
         raise NotImplementedError
 
-    def put(self,task_data,submission_data=None, depends_on=None):
+    def put(self,task_data, submission_data=None, depends_on=None):
         print(dir(self.client.worker))
 
         return self.client.worker.questionTask(
                     worker_id=self.worker_id,
-                    task_data=task_data,
+                    task_payload=dict(
+                        task_data=task_data,
+                        submission_data=submission_data,
+                    ),
                     queue=self.queue,
                 ).response().result
 
@@ -140,7 +146,7 @@ class QueueProxy(DataFacts, Queue):
     def task_done(self):
         self.logger.info("task done, closing: %s : %s", self.current_task.key, self.current_task)
         self.logger.info("task done, stored key: %s", self.current_task_stored_key)
-        self.logger.info("current task: %s", self.current_task.as_dict)
+        self.logger.info("current task: %s", repr(self.current_task.as_dict)[:500]+" ...")
 
         r = self.client.worker.answer(worker_id=self.worker_id, 
                                       queue=self.queue, 
@@ -158,10 +164,12 @@ class QueueProxy(DataFacts, Queue):
             task_key = task.key
 
         if update_entry is None:
-            update_entry = json.loads(update_entry or '{}')
+            update_entry = {}
+        else:
+            update_entry = json.loads(update_entry)
 
         self.logger.info("moving task %s from %s to %s", task_key, fromk, tok)
-        self.logger.info("moving task uses update entry %s", update_entry)
+        self.logger.info("moving task uses update entry %s", repr(update_entry)[:300])
 
         self.logger.info(dir(self.client.tasks))
 
@@ -230,6 +238,7 @@ class QueueProxy(DataFacts, Queue):
         """
         """
         return self.client.worker.callback(
+                    worker_id = self.worker_id,
                     payload=dict(
                             url = url,
                             params = params,
